@@ -135,7 +135,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.3.875");
+    setStatus("Using qgvdial version 0.3.888");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -175,6 +175,9 @@ MainWindow::onCleanupLogsArray()
         ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
     } while (0); // End cleanup block (not a loop)
 
+    // Flush the log. flush it!
+    qgv_LogFlush ();
+
     logsTimer.start (timeout);
 }//MainWindow::onCleanupLogsArray
 
@@ -542,7 +545,7 @@ MainWindow::initQML ()
     bool rv;
     // Connect all signals to slots in this class.
     rv = connect (gObj, SIGNAL (sigCall (QString)),
-                   this, SLOT   (dialNow (QString)));
+                  this, SLOT   (dialNow (QString)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
     rv = connect (
@@ -593,6 +596,15 @@ MainWindow::initQML ()
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
+    rv = connect (gObj, SIGNAL (sigRefreshContacts()),
+                  &oContacts, SLOT(refreshContacts()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL(sigRefreshInbox()),
+                  &oInbox,   SLOT(refresh()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     // Now do the settings page
     if (!connectSettingsSignals ()) {
         exit (1);
@@ -681,22 +693,6 @@ MainWindow::connectSettingsSignals()
         rv = connect (obj , SIGNAL(sigPinRefresh()),
                       this, SLOT  (refreshPinSettings()));
         Q_ASSERT(rv);
-        rv = connect (obj , SIGNAL (sigRefresh ()),
-                      this, SLOT   (onRefresh ()));
-        Q_ASSERT(rv);
-        if (!rv) { break; }
-        rv = connect (obj , SIGNAL (sigRefreshAll ()),
-                      this, SLOT   (onRefreshAll ()));
-        Q_ASSERT(rv);
-        if (!rv) { break; }
-        rv = connect (obj , SIGNAL (sigRefreshInbox ()),
-                      this, SLOT   (onSigRefreshInbox ()));
-        Q_ASSERT(rv);
-        if (!rv) { break; }
-        rv = connect (obj , SIGNAL (sigRefreshContacts ()),
-                      this, SLOT   (onSigRefreshContacts ()));
-        Q_ASSERT(rv);
-        if (!rv) { break; }
 
         rv = connect (obj , SIGNAL (sigSendLogs ()),
                       this, SLOT   (onSigSendLogs ()));
@@ -1277,7 +1273,7 @@ MainWindow::dialComplete (AsyncTaskToken *token)
         if (bDialCancelled) {
             setStatus ("Cancelled dial out");
         } else if (NULL == ctx->fallbackCi) {
-            // Not currently in fallback modem and there was a problem
+            // Not currently in fallback mode and there was a problem
             // ... so start fallback mode
             Q_DEBUG("Attempting fallback dial");
             bReleaseContext = false;
@@ -1661,39 +1657,13 @@ MainWindow::onRegPhoneSelectionChange (int index)
 void
 MainWindow::onRefresh ()
 {
-    qDebug ("Refresh all requested.");
+    Q_DEBUG ("Refresh all requested.");
 
     refreshRegisteredNumbers ();
     oInbox.refresh ();
     oContacts.refreshContacts ();
 }//MainWindow::onRefresh
 
-void
-MainWindow::onRefreshAll ()
-{
-    qDebug ("Refresh all requested.");
-
-    refreshRegisteredNumbers ();
-    oInbox.refreshFullInbox ();
-    oContacts.refreshAllContacts ();
-}//MainWindow::onRefreshAll
-
-void
-MainWindow::onSigRefreshContacts()
-{
-    qDebug ("Refresh Contacts requested.");
-
-    oContacts.refreshContacts ();
-}//MainWindow::onSigRefreshContacts
-
-void
-MainWindow::onSigRefreshInbox()
-{
-    qDebug ("Refresh inbox requested.");
-
-    oInbox.refresh ();
-}//MainWindow::onSigRefreshInbox
-
 void
 MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
                               const QString &host, int port, bool bRequiresAuth,
@@ -2006,9 +1976,11 @@ MainWindow::fallbackDialout (DialContext *ctx)
 
     ctx->fallbackCi = cif.getFallbacks()[0];
     bool rv = connect (ctx->fallbackCi, SIGNAL(callInitiated(bool,void*)),
-                      this,            SLOT  (onFallbackDialout(bool,void*)));
+                       this,          SLOT(onFallbackDialout(bool,void*)));
     Q_ASSERT(rv); Q_UNUSED(rv);
     GVApi::simplify_number (strFull);
+
+    Q_DEBUG(QString("Attempting fallback dial out to %1").arg(strFull));
     ctx->fallbackCi->initiateCall (strFull, ctx);
 }//MainWindow::fallbackDialout
 
@@ -2026,6 +1998,8 @@ MainWindow::onFallbackDialout (bool bSuccess, void *v_ctx)
         return;
     }
 
+    Q_DEBUG("Fallback dial is in progress. Now send DTMF");
+
     QString strDTMF;
     strDTMF = "p*p2p" + ctx->strTarget;
     // Add the pin if it is there
@@ -2262,7 +2236,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.3.875");
+        QDomText appVerText = doc.createTextNode("0.3.888");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -2326,7 +2300,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
         QDateTime dt = token->inParams["date"].toDateTime();
         QString body = QString("Logs captured at %1 \n")
                                 .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.875 \n";
+        body += "qgvdial version = 0.3.888 \n";
         body += QString("OS: %1 \n").arg(osd.getOSDetails());
         body += QString("Logs are in %1 \n").arg(strReply);
         url.addQueryItem ("body", body);
