@@ -137,9 +137,6 @@ private slots:
 
     //! Invoked when user invokes refresh
     void onRefresh ();
-    void onRefreshAll ();
-    void onSigRefreshContacts();
-    void onSigRefreshInbox();
 
     //! Status messages timeout
     void onStatusTimerTick ();
